from . import parameter
from . import parameter_group

Parameter = parameter.Parameter
ParameterGroup = parameter_group.ParameterGroup
